/**
 * Types de termes de la base.
 */
export const types = {
    disease: 'Maladie',
    symptom: 'Symptôme',
    sign: 'Signe'
};

/**
 * Liste des termes de la base de données, contenant des maladies, des signes
 * et des symptômes.
 */
export const terms = {
    Q2840: {
        id: 'Q2840',
        name: 'Grippe',
        types: [types.disease],
        weight: 0.000035
    },
    Q154882: {
        id: 'Q154882',
        name: 'Légionellose',
        types: [types.disease],
        weight: 0.000015
    },
    Q155098: {
        id: 'Q155098',
        name: 'Leptospirose',
        types: [types.disease],
        weight: 0.00001
    },
    Q326663: {
        id: 'Q326663',
        name: 'Encéphalite à tiques',
        types: [types.disease],
        weight: 0.000001
    },
    Q133780: {
        id: 'Q133780',
        name: 'Peste',
        types: [types.disease],
        weight: 0.000032
    },
    Q38933: {
        id: 'Q38933',
        name: 'Fièvre',
        types: [types.symptom]
    },
    Q474959: {
        id: 'Q474959',
        name: 'Myalgie',
        types: [types.symptom]
    },
    Q86: {
        id: 'Q86',
        name: 'Céphalée',
        types: [types.sign]
    },
    Q1115038: {
        id: 'Q1115038',
        name: 'Rhinorrhée',
        types: [types.symptom]
    },
    Q9690: {
        id: 'Q9690',
        name: 'Fatigue',
        types: [types.symptom]
    },
    Q127076: {
        id: 'Q127076',
        name: 'Vomissement',
        types: [types.symptom, types.sign]
    },
    Q178061: {
        id: 'Q178061',
        name: 'Choc circulatoire',
        types: [types.disease],
        weight: 0.000038
    },
    Q35805: {
        id: 'Q35805',
        name: 'Toux',
        types: [types.symptom, types.sign]
    },
    Q647099: {
        id: 'Q647099',
        name: 'Hémoptysie',
        types: [types.symptom]
    },
    Q653197: {
        id: 'Q653197',
        name: 'Rash',
        types: [types.symptom, types.sign]
    },
    Q160796: {
        id: 'Q160796',
        name: 'Syndrome confusionnel',
        types: [types.disease],
        weight: 0.000004
    },
    Q186235: {
        id: 'Q186235',
        name: 'Myocardite',
        types: [types.disease],
        weight: 0.0000075
    },
    Q476921: {
        id: 'Q476921',
        name: 'Insuffisance rénale',
        types: [types.disease],
        weight: 0.0000046
    },
    Q281289: {
        id: 'Q281289',
        name: 'Photophobie',
        types: [types.sign]
    },
    Q159557: {
        id: 'Q159557',
        name: 'Coma',
        types: [types.sign]
    }
};

/**
 * Liste des relations de type « a pour symptôme » entre deux termes.
 */
export const hasSymptom = [
    ['Q2840', 'Q38933'],
    ['Q2840', 'Q1115038'],
    ['Q2840', 'Q474959'],
    ['Q2840', 'Q86'],
    ['Q2840', 'Q9690'],

    ['Q154882', 'Q86'],
    ['Q154882', 'Q38933'],
    ['Q154882', 'Q35805'],
    ['Q154882', 'Q474959'],

    ['Q155098', 'Q38933'],
    ['Q155098', 'Q474959'],
    ['Q155098', 'Q86'],
    ['Q155098', 'Q476921'],
    ['Q155098', 'Q186235'],
    ['Q155098', 'Q653197'],

    ['Q326663', 'Q86'],
    ['Q326663', 'Q474959'],
    ['Q326663', 'Q38933'],
    ['Q326663', 'Q9690'],
    ['Q326663', 'Q281289'],
    ['Q326663', 'Q159557'],
    ['Q326663', 'Q127076'],

    ['Q133780', 'Q38933'],
    ['Q133780', 'Q86'],
    ['Q133780', 'Q127076'],
    ['Q133780', 'Q474959'],
    ['Q133780', 'Q178061'],
    ['Q133780', 'Q35805'],
    ['Q133780', 'Q647099'],
    ['Q133780', 'Q653197'],
    ['Q133780', 'Q160796']
];

/**
 * Liste des relations de type « est un symptôme de » entre deux termes.
 */
export const symptomOf = hasSymptom.map(([from, to]) => [to, from]);
